function [ret,x0,str,ts,xts]=regderb3(t,x,u,flag);
%REGDERB3	is the M-file description of the SIMULINK system named REGDERB3.
%	The block-diagram can be displayed by typing: REGDERB3.
%
%	SYS=REGDERB3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGDERB3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGDERB3 with a FLAG of zero:
%	[SIZES]=REGDERB3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[3,32,1243,928])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'PHASE DE DETUMBLING']])
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'PHASE DE DETUMBLING']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[573,0,578,5])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1030,710,1205,776])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1035,795,1210,861])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem1/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem1/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est ACQ_DAT3.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est ACQ_DAT3.M']],...
		'Font Size',14,...
		'position',[405,125,410,130])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,90,500,95])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[835,590,1185,626])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[522,486,1216,779])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[660,278,745,332])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''acq_dat3'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[850,440,1065,511])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[825,275,830,280])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[825,340,830,345])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,76,1267,1003])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[915,624,1000,656])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[800,272,900,298])

add_block('built-in/Note',[sys,'/','Subsystem/Vrifications Poinsot'])
set_param([sys,'/','Subsystem/Vrifications Poinsot'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[965,295,970,300])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope'])
set_param([sys,'/','Subsystem/Scope'],...
		'Vgain','0.200000',...
		'Hgain','5000.000000',...
		'Vmax','0.400000',...
		'Hmax','10000.000000',...
		'Window',[314,357,1072,756],...
		'position',[865,130,895,160])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[410,455,415,460])

add_block('built-in/Note',[sys,'/',['Subsystem/Mettre une saturation',13,'',13,'']])
set_param([sys,'/',['Subsystem/Mettre une saturation',13,'',13,'']],...
		'position',[150,730,155,735])

add_block('built-in/Note',[sys,'/','Subsystem/Reste  mettre un stop'])
set_param([sys,'/','Subsystem/Reste  mettre un stop'],...
		'position',[155,665,160,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']])
set_param([sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']],...
		'position',[150,585,155,590])

add_block('built-in/Note',[sys,'/','Subsystem/Mettre des retards'])
set_param([sys,'/','Subsystem/Mettre des retards'],...
		'position',[145,555,150,560])

add_block('built-in/Note',[sys,'/','Subsystem/Mettre des filtres'])
set_param([sys,'/','Subsystem/Mettre des filtres'],...
		'position',[140,525,145,530])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[260,415,280,435])

add_block('built-in/To File',[sys,'/','Subsystem/To File4'])
set_param([sys,'/','Subsystem/To File4'],...
		'ForeGround',1,...
		'BackGround',2,...
		'File name','initpqrQ.mat',...
		'Matrix name','initpqrQ',...
		'position',[350,286,470,334])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[285,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[660,380;660,335;715,335])
add_line([sys,'/','Subsystem'],[765,335;800,335])
add_line([sys,'/','Subsystem'],[660,335;660,285;795,285])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;910,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[685,210;685,145;860,145])
add_line([sys,'/','Subsystem'],[320,425;320,310;345,310])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[880,286,1075,359])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[550,480,555,485])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[555,340,560,345])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[660,409,760,461])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[535,289,595,576])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[160,453,375,557])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[450,505,455,510])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,50,1267,977])

add_block('built-in/Note',[sys,'/','UnNamed1/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'])
set_param([sys,'/','UnNamed1/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',24,...
		'position',[545,15,550,20])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,50,1267,977])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'position',[275,506,485,554])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain3'])
set_param([sys,'/','UnNamed1/Gain3'],...
		'hide name',0,...
		'position',[505,422,530,448])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[75,135,80,140])

add_block('built-in/Note',[sys,'/','UnNamed1/Ensemble des couples'])
set_param([sys,'/','UnNamed1/Ensemble des couples'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[380,700,385,705])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[155,107,200,318])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']])
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[690,507,790,553])

add_block('built-in/Note',[sys,'/',['UnNamed1/Somme des couples',13,'externes']])
set_param([sys,'/',['UnNamed1/Somme des couples',13,'externes']],...
		'position',[635,685,640,690])

add_block('built-in/Note',[sys,'/','UnNamed1/Loi en BPOINT'])
set_param([sys,'/','UnNamed1/Loi en BPOINT'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[380,670,385,675])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression',13,'ventuelle des ',13,'perturbations']])
set_param([sys,'/',['UnNamed1/Suppression',13,'ventuelle des ',13,'perturbations']],...
		'position',[545,465,550,470])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[245,130,250,135])


%     Subsystem  'UnNamed1/Subsystem2'.

new_system([sys,'/','UnNamed1/Subsystem2'])
set_param([sys,'/','UnNamed1/Subsystem2'],'Location',[188,389,1095,933])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem2/Mux4'])
set_param([sys,'/','UnNamed1/Subsystem2/Mux4'],...
		'hide name',0,...
		'inputs','3',...
		'position',[505,157,540,273])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem2/Mux5'])
set_param([sys,'/','UnNamed1/Subsystem2/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[505,312,540,428])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem2/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem2/To Workspace6'],...
		'hide name',0,...
		'mat-name','cpl_roue_teta',...
		'buffer','points_trace',...
		'position',[405,340,485,360])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/Gain10'])
set_param([sys,'/','UnNamed1/Subsystem2/Gain10'],...
		'hide name',0,...
		'Gain','0',...
		'position',[305,316,340,344])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/Gain9'])
set_param([sys,'/','UnNamed1/Subsystem2/Gain9'],...
		'hide name',0,...
		'Gain','0',...
		'position',[305,396,340,424])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/Gain8'])
set_param([sys,'/','UnNamed1/Subsystem2/Gain8'],...
		'hide name',0,...
		'Gain','-4e-6',...
		'position',[295,352,375,388])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem2/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem2/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[115,353,175,387])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem2/Roue'])
set_param([sys,'/','UnNamed1/Subsystem2/Roue'],...
		'hide name',0,...
		'position',[275,110,280,115])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/Gain6'])
set_param([sys,'/','UnNamed1/Subsystem2/Gain6'],...
		'hide name',0,...
		'Gain','0',...
		'position',[215,161,250,189])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem2/in_2'])
set_param([sys,'/','UnNamed1/Subsystem2/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[65,360,85,380])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem2/Demux4'])
set_param([sys,'/','UnNamed1/Subsystem2/Demux4'],...
		'hide name',0,...
		'outputs','3',...
		'position',[195,312,235,428])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/Gain7'])
set_param([sys,'/','UnNamed1/Subsystem2/Gain7'],...
		'hide name',0,...
		'Gain','0',...
		'position',[430,241,465,269])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/gain_roue'])
set_param([sys,'/','UnNamed1/Subsystem2/gain_roue'],...
		'hide name',0,...
		'Gain','-1e-3',...
		'position',[325,190,395,240])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem2/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem2/Sum1'],...
		'inputs','+-',...
		'position',[265,206,280,239])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem2/Constant'])
set_param([sys,'/','UnNamed1/Subsystem2/Constant'],...
		'Value','vitesse_rotation',...
		'position',[125,215,230,245])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem2/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem2/To Workspace5'],...
		'hide name',0,...
		'mat-name','cpl_roue_q',...
		'buffer','points_trace',...
		'position',[415,190,495,210])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem2/COMMANDE DE LA ROUE DE TANGAGE'])
set_param([sys,'/','UnNamed1/Subsystem2/COMMANDE DE LA ROUE DE TANGAGE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[465,15,470,20])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem2/Rappel proportionnel',13,'au',13,'tangage']])
set_param([sys,'/',['UnNamed1/Subsystem2/Rappel proportionnel',13,'au',13,'tangage']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[385,425,390,430])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem2/Rappel proportionnel',13,' la',13,'rotation q-w0']])
set_param([sys,'/',['UnNamed1/Subsystem2/Rappel proportionnel',13,' la',13,'rotation q-w0']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[380,80,385,85])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem2/Sum'])
set_param([sys,'/','UnNamed1/Subsystem2/Sum'],...
		'hide name',0,...
		'position',[640,242,685,333])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem2/To Workspace4'])
set_param([sys,'/','UnNamed1/Subsystem2/To Workspace4'],...
		'hide name',0,...
		'mat-name','cpl_roue',...
		'buffer','points_trace',...
		'position',[825,240,905,260])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem2/Limiteur couple',13,'roue  4e-6 Nn']])
set_param([sys,'/',['UnNamed1/Subsystem2/Limiteur couple',13,'roue  4e-6 Nn']],...
		'position',[765,325,770,330])

add_block('built-in/Saturation',[sys,'/','UnNamed1/Subsystem2/Saturation'])
set_param([sys,'/','UnNamed1/Subsystem2/Saturation'],...
		'Lower Limit','-4e-6',...
		'Upper Limit','4e-6',...
		'position',[740,278,770,302])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem2/out_1'])
set_param([sys,'/','UnNamed1/Subsystem2/out_1'],...
		'hide name',0,...
		'position',[830,280,850,300])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/Gain11'])
set_param([sys,'/','UnNamed1/Subsystem2/Gain11'],...
		'hide name',0,...
		'position',[565,201,600,229])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem2/Gain12'])
set_param([sys,'/','UnNamed1/Subsystem2/Gain12'],...
		'hide name',0,...
		'position',[560,356,595,384])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem2/in_1'])
set_param([sys,'/','UnNamed1/Subsystem2/in_1'],...
		'hide name',0,...
		'position',[20,205,40,225])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem2/Demux3'])
set_param([sys,'/','UnNamed1/Subsystem2/Demux3'],...
		'hide name',0,...
		'outputs','3',...
		'position',[75,157,115,273])
add_line([sys,'/','UnNamed1/Subsystem2'],[120,255;425,255])
add_line([sys,'/','UnNamed1/Subsystem2'],[255,175;500,175])
add_line([sys,'/','UnNamed1/Subsystem2'],[120,175;210,175])
add_line([sys,'/','UnNamed1/Subsystem2'],[470,255;500,255])
add_line([sys,'/','UnNamed1/Subsystem2'],[45,215;70,215])
add_line([sys,'/','UnNamed1/Subsystem2'],[90,370;110,370])
add_line([sys,'/','UnNamed1/Subsystem2'],[180,370;190,370])
add_line([sys,'/','UnNamed1/Subsystem2'],[240,370;290,370])
add_line([sys,'/','UnNamed1/Subsystem2'],[345,330;500,330])
add_line([sys,'/','UnNamed1/Subsystem2'],[345,410;500,410])
add_line([sys,'/','UnNamed1/Subsystem2'],[380,370;500,370])
add_line([sys,'/','UnNamed1/Subsystem2'],[240,330;300,330])
add_line([sys,'/','UnNamed1/Subsystem2'],[240,410;300,410])
add_line([sys,'/','UnNamed1/Subsystem2'],[400,215;500,215])
add_line([sys,'/','UnNamed1/Subsystem2'],[390,370;400,350])
add_line([sys,'/','UnNamed1/Subsystem2'],[690,290;735,290])
add_line([sys,'/','UnNamed1/Subsystem2'],[775,290;825,290])
add_line([sys,'/','UnNamed1/Subsystem2'],[790,290;790,250;820,250])
add_line([sys,'/','UnNamed1/Subsystem2'],[400,215;410,200])
add_line([sys,'/','UnNamed1/Subsystem2'],[120,215;260,215])
add_line([sys,'/','UnNamed1/Subsystem2'],[235,230;260,230])
add_line([sys,'/','UnNamed1/Subsystem2'],[285,225;295,225;295,215;320,215])
add_line([sys,'/','UnNamed1/Subsystem2'],[545,215;560,215])
add_line([sys,'/','UnNamed1/Subsystem2'],[605,215;620,215;620,265;635,265])
add_line([sys,'/','UnNamed1/Subsystem2'],[545,370;555,370])
add_line([sys,'/','UnNamed1/Subsystem2'],[600,370;610,370;610,310;635,310])
set_param([sys,'/','UnNamed1/Subsystem2'],...
		'Mask Display','COUPLE ROUE\n\nSUR LE TANGAGE\n\nSEUL')


%     Finished composite block 'UnNamed1/Subsystem2'.

set_param([sys,'/','UnNamed1/Subsystem2'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'position',[275,395,480,470])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m2'])
set_param([sys,'/','UnNamed1/magneto.m2'],...
		'hide name',0,...
		'MATLAB Fcn','jw_rot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue',...
		'position',[360,206,495,264])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[360,131,495,189])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[55,205,75,225])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[1080,250,1100,270])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'position',[1015,247,1040,273])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'inputs','+++',...
		'position',[945,113,965,407])

add_block('built-in/Note',[sys,'/',['UnNamed1/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']])
set_param([sys,'/',['UnNamed1/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1065,415,1070,420])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain4'])
set_param([sys,'/','UnNamed1/Gain4'],...
		'hide name',0,...
		'position',[845,517,870,543])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression possible',13,'de tous les couples']])
set_param([sys,'/',['UnNamed1/Suppression possible',13,'de tous les couples']],...
		'position',[865,545,870,550])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[525,608,565,642])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain5'])
set_param([sys,'/','UnNamed1/Gain5'],...
		'hide name',0,...
		'position',[560,222,585,248])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression ',13,'possible de la roue']])
set_param([sys,'/',['UnNamed1/Suppression ',13,'possible de la roue']],...
		'position',[575,180,580,185])


%     Subsystem  'UnNamed1/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem1'],'Location',[77,177,1249,843])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace3'],...
		'hide name',0,...
		'mat-name','mz_deriv',...
		'buffer','points_trace',...
		'position',[800,160,880,180])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace2'],...
		'hide name',0,...
		'mat-name','my_deriv',...
		'buffer','points_trace',...
		'position',[800,125,880,145])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace1'],...
		'hide name',0,...
		'mat-name','mx_deriv',...
		'buffer','points_trace',...
		'position',[800,90,880,110])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']])
set_param([sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']],...
		'MATLAB Fcn','mom_magn(u)',...
		'Output Width','3',...
		'position',[580,248,640,282])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']])
set_param([sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[1075,395,1080,400])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Outport'])
set_param([sys,'/','UnNamed1/Subsystem1/Outport'],...
		'position',[1135,320,1155,340])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux1'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[880,202,930,453])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[965,313,1025,347])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1075,235,1155,255])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[780,194,810,336])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem1/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[670,195,710,335])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[525,174,560,356])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/B'])
set_param([sys,'/','UnNamed1/Subsystem1/B'],...
		'position',[505,285,510,290])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/B''']])
set_param([sys,'/',['UnNamed1/Subsystem1/B''']],...
		'position',[510,190,515,195])

add_block('built-in/Derivative',[sys,'/',['UnNamed1/Subsystem1/Drive de B',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/Drive de B',13,'en axes satellite']],...
		'position',[415,182,490,258])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/in_1'],...
		'position',[45,210,65,230])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem1/Gain matriciel'])
set_param([sys,'/','UnNamed1/Subsystem1/Gain matriciel'],...
		'orientation',2,...
		'MATLAB Fcn','gain_mat(u)',...
		'Output Width','9',...
		'position',[235,373,295,407])

add_block('built-in/To File',[sys,'/','UnNamed1/Subsystem1/To File'])
set_param([sys,'/','UnNamed1/Subsystem1/To File'],...
		'orientation',2,...
		'hide name',0,...
		'File name','gain.mat',...
		'Matrix name','gain_matriciel',...
		'position',[35,374,180,406])


%     Subsystem  ['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],...
		'position',[115,183,315,257])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[70,265,75,270])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Sortie B',13,'axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/Sortie B',13,'axes satellite']],...
		'position',[365,175,370,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[400,102,405,107])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'])
set_param([sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[555,10,560,15])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,220;775,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[730,220;730,100;795,100])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,265;775,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[750,265;750,135;795,135])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,310;775,310])
add_line([sys,'/','UnNamed1/Subsystem1'],[765,310;765,170;795,170])
add_line([sys,'/','UnNamed1/Subsystem1'],[815,265;875,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[645,265;665,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[495,220;520,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[70,220;110,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[565,265;575,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[230,390;185,390])
add_line([sys,'/','UnNamed1/Subsystem1'],[320,220;410,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[375,220;375,310;520,310])
add_line([sys,'/','UnNamed1/Subsystem1'],[375,305;375,390;300,390])
add_line([sys,'/','UnNamed1/Subsystem1'],[375,388;875,390])
add_line([sys,'/','UnNamed1/Subsystem1'],[935,330;960,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[1030,330;1130,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[1030,330;1030,245;1070,245])
set_param([sys,'/','UnNamed1/Subsystem1'],...
		'Mask Display','REGULATION PAR\nDERIVEE DU CHAMP MAGNETIQUE')


%     Finished composite block 'UnNamed1/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem1'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'position',[270,583,495,667])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'hide name',0,...
		'position',[530,517,555,543])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[215,250,220,255])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux2'])
set_param([sys,'/','UnNamed1/Demux2'],...
		'hide name',0,...
		'outputs','[3 4]',...
		'position',[170,398,215,467])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum'])
set_param([sys,'/','UnNamed1/Sum'],...
		'inputs','+++',...
		'position',[630,388,665,672])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux1'])
set_param([sys,'/','UnNamed1/Demux1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'outputs','3',...
		'position',[570,353,615,407])


%     Subsystem  'UnNamed1/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem'],'Location',[271,671,1123,971])

add_block('built-in/Scope',[sys,'/','UnNamed1/Subsystem/Scope'])
set_param([sys,'/','UnNamed1/Subsystem/Scope'],...
		'Vgain','2000.000000',...
		'Hgain','4000.000000',...
		'Vmax','4000.000000',...
		'Hmax','8000.000000',...
		'Window',[39,580,681,1020],...
		'position',[630,95,660,125])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'Gain','-1',...
		'position',[115,122,145,148])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Gain3'])
set_param([sys,'/','UnNamed1/Subsystem/Gain3'],...
		'Gain','30/pi',...
		'position',[445,118,470,152])

add_block('built-in/Integrator',[sys,'/','UnNamed1/Subsystem/Integrator2'])
set_param([sys,'/','UnNamed1/Subsystem/Integrator2'],...
		'BackGround',7,...
		'Initial','rotation_initiale',...
		'position',[325,113,370,157])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/To Workspace7'])
set_param([sys,'/','UnNamed1/Subsystem/To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[235,189,340,221])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[455,179,600,211])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[515,120,595,150])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['UnNamed1/Subsystem/Vitesse roue ',13,'en rd//s']],...
		'position',[520,210,525,215])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Gain5'])
set_param([sys,'/','UnNamed1/Subsystem/Gain5'],...
		'BackGround',7,...
		'Gain','1/jroue',...
		'position',[240,115,275,155])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/in_1'],...
		'position',[20,125,40,145])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['UnNamed1/Subsystem/Vitesse roue',13,'en tours//mn']],...
		'position',[455,70,460,75])
add_line([sys,'/','UnNamed1/Subsystem'],[475,135;510,135])
add_line([sys,'/','UnNamed1/Subsystem'],[490,135;490,110;625,110])
add_line([sys,'/','UnNamed1/Subsystem'],[150,135;235,135])
add_line([sys,'/','UnNamed1/Subsystem'],[175,135;175,205;230,205])
add_line([sys,'/','UnNamed1/Subsystem'],[45,135;110,135])
add_line([sys,'/','UnNamed1/Subsystem'],[280,135;320,135])
add_line([sys,'/','UnNamed1/Subsystem'],[375,135;440,135])
add_line([sys,'/','UnNamed1/Subsystem'],[395,135;395,195;450,195])
set_param([sys,'/','UnNamed1/Subsystem'],...
		'Mask Display','EVOLUTION DE LA\nVITESSE DE LA ROUE')


%     Finished composite block 'UnNamed1/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[715,349,860,411])


%     Subsystem  'UnNamed1/Subsystem4'.

new_system([sys,'/','UnNamed1/Subsystem4'])
set_param([sys,'/','UnNamed1/Subsystem4'],'Location',[419,287,1104,467])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Subsystem4/Derivative'])
set_param([sys,'/','UnNamed1/Subsystem4/Derivative'],...
		'position',[375,31,435,79])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Mux'])
set_param([sys,'/','UnNamed1/Subsystem4/Mux'],...
		'inputs','[3 3]',...
		'position',[485,25,520,140])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/out_1'])
set_param([sys,'/','UnNamed1/Subsystem4/out_1'],...
		'position',[550,75,570,95])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem4/in_1'])
set_param([sys,'/','UnNamed1/Subsystem4/in_1'],...
		'position',[15,75,35,95])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem4/Demux1'],...
		'outputs','[3 4]',...
		'position',[85,28,130,137])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/To Workspace12'])
set_param([sys,'/','UnNamed1/Subsystem4/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p_q_r',...
		'buffer','1',...
		'position',[180,37,275,73])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem4/Angles  rd'])
set_param([sys,'/','UnNamed1/Subsystem4/Angles  rd'],...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'Mask Display','Angles (rd )',...
		'position',[185,93,275,127])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Q'])
set_param([sys,'/','UnNamed1/Subsystem4/Q'],...
		'position',[145,85,150,90])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/pqr'])
set_param([sys,'/','UnNamed1/Subsystem4/pqr'],...
		'position',[150,30,155,35])
add_line([sys,'/','UnNamed1/Subsystem4'],[440,55;480,55])
add_line([sys,'/','UnNamed1/Subsystem4'],[280,110;480,110])
add_line([sys,'/','UnNamed1/Subsystem4'],[300,110;300,55;370,55])
add_line([sys,'/','UnNamed1/Subsystem4'],[135,110;180,110])
add_line([sys,'/','UnNamed1/Subsystem4'],[135,55;175,55])
add_line([sys,'/','UnNamed1/Subsystem4'],[525,85;545,85])
add_line([sys,'/','UnNamed1/Subsystem4'],[40,85;80,85])
set_param([sys,'/','UnNamed1/Subsystem4'],...
		'Mask Display','TRANSFERT VALEURS FINALES\nEN VALEURS INITIALES')


%     Finished composite block 'UnNamed1/Subsystem4'.

set_param([sys,'/','UnNamed1/Subsystem4'],...
		'hide name',0,...
		'position',[295,745,500,805])

add_block('built-in/To File',[sys,'/','UnNamed1/To File'])
set_param([sys,'/','UnNamed1/To File'],...
		'ForeGround',1,...
		'BackGround',2,...
		'File name','init_tmc.mat',...
		'Matrix name','init_by3',...
		'position',[545,751,665,799])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace14'])
set_param([sys,'/','UnNamed1/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'mat-name','init_by3',...
		'buffer','1',...
		'position',[560,817,655,853])
add_line([sys,'/','UnNamed1'],[205,160;355,160])
add_line([sys,'/','UnNamed1'],[970,260;1010,260])
add_line([sys,'/','UnNamed1'],[1045,260;1075,260])
add_line([sys,'/','UnNamed1'],[80,215;150,215])
add_line([sys,'/','UnNamed1'],[500,160;940,160])
add_line([sys,'/','UnNamed1'],[250,160;250,235;355,235])
add_line([sys,'/','UnNamed1'],[490,530;525,530])
add_line([sys,'/','UnNamed1'],[500,625;520,625])
add_line([sys,'/','UnNamed1'],[120,215;120,530;270,530])
add_line([sys,'/','UnNamed1'],[120,530;120,625;265,625])
add_line([sys,'/','UnNamed1'],[560,530;625,530])
add_line([sys,'/','UnNamed1'],[570,625;625,625])
add_line([sys,'/','UnNamed1'],[670,530;685,530])
add_line([sys,'/','UnNamed1'],[620,380;710,380])
add_line([sys,'/','UnNamed1'],[485,435;500,435])
add_line([sys,'/','UnNamed1'],[535,435;625,435])
add_line([sys,'/','UnNamed1'],[555,435;565,380])
add_line([sys,'/','UnNamed1'],[795,530;840,530])
add_line([sys,'/','UnNamed1'],[875,530;890,530;890,360;940,360])
add_line([sys,'/','UnNamed1'],[500,235;555,235])
add_line([sys,'/','UnNamed1'],[590,235;875,235;875,260;940,260])
add_line([sys,'/','UnNamed1'],[220,415;270,415])
add_line([sys,'/','UnNamed1'],[220,450;270,450])
add_line([sys,'/','UnNamed1'],[120,435;165,435])
add_line([sys,'/','UnNamed1'],[120,625;120,775;290,775])
add_line([sys,'/','UnNamed1'],[505,775;540,775])
add_line([sys,'/','UnNamed1'],[515,775;515,835;555,835])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[165,318,390,402])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[460,325,465,330])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[405,570,410,575])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[220,595,225,600])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[630,590,635,595])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[450,655,455,660])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[100,795,305,856])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,50,1012,686])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[350,780,580,866])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[105,710,305,776])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[615,720,790,776])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[610,795,785,861])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx_deriv, my_deriv, mz_deriv',...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[335,710,585,771])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[605,155,610,160])

add_block('built-in/Note',[sys,'/',['SIMULATION regderb3.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur q - w0 et tangage )']])
set_param([sys,'/',['SIMULATION regderb3.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur q - w0 et tangage )']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['SIMULATION regderb3.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur q - w0 et tangage )']],...
		'Font Size',18,...
		'position',[615,65,620,70])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[60,53,95,87])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance acq_dat3.m']])
set_param([sys,'/',['L''initialisation',13,' lance acq_dat3.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1145,445,1150,450])

add_block('built-in/Note',[sys,'/',['Cette simulation permet grce aux fichiers init_tmc.mat et initpqrQ.mat permet ',13,'de rcuprer les valeurs finales pour exploitation ou la simulation suivante']])
set_param([sys,'/',['Cette simulation permet grce aux fichiers init_tmc.mat et initpqrQ.mat permet ',13,'de rcuprer les valeurs finales pour exploitation ou la simulation suivante']],...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['Cette simulation permet grce aux fichiers init_tmc.mat et initpqrQ.mat permet ',13,'de rcuprer les valeurs finales pour exploitation ou la simulation suivante']],...
		'Font Size',14,...
		'position',[585,205,590,210])
add_line(sys,[765,435;785,435;785,590;75,590;75,505;155,505])
add_line(sys,[600,435;655,435])
add_line(sys,[395,360;530,360])
add_line(sys,[380,505;530,505])
add_line(sys,[785,435;785,305;875,305])
add_line(sys,[635,435;635,340;875,340])
add_line(sys,[75,505;75,360;160,360])
add_line(sys,[785,305;750,305])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
